@@ -7,7 +7,9 @@ distribution url + callback url paths.
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Dict, List
+
+from ...base import HookArgsBaseModel
 
 if TYPE_CHECKING:
     from .....context import CfnginContext
@@ -15,6 +17,34 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
+class HookArgs(HookArgsBaseModel):
+    """Hook arguments."""
+
+    alternate_domains: List[str]
+    """A list of any alternate domains that need to be listed with the primary
+    distribution domain.
+
+    """
+
+    client_id: str
+    """Client ID."""
+
+    distribution_domain: str
+    """Distribution domain."""
+
+    oauth_scopes: List[str]
+    """A list of all available validation scopes for oauth."""
+
+    redirect_path_sign_in: str
+    """The redirect path after sign in."""
+
+    redirect_path_sign_out: str
+    """The redirect path after sign out."""
+
+    supported_identity_providers: List[str] = []
+    """Supported identity providers."""
+
+
 def get_redirect_uris(
     domains: List[str], redirect_path_sign_in: str, redirect_path_sign_out: str
 ) -> Dict[str, List[str]]:
@@ -25,54 +55,38 @@ def get_redirect_uris(
     }
 
 
-def update(
-    context: CfnginContext,
-    *,
-    alternate_domains: List[str],
-    client_id: str,
-    distribution_domain: str,
-    oauth_scopes: List[str],
-    redirect_path_sign_in: str,
-    redirect_path_sign_out: str,
-    supported_identity_providers: Optional[List[str]] = None,
-    **_: Any,
-) -> bool:
+def update(context: CfnginContext, *__args: Any, **kwargs: Any) -> bool:
     """Update the callback urls for the User Pool Client.
 
     Required to match the redirect_uri being sent which contains
     our distribution and alternate domain names.
 
+    Arguments parsed by
+    :class:`~runway.cfngin.hooks.staticsite.auth_at_edge.client_updater.HookArgs`.
+
     Args:
         context: The context instance.
-        alternate_domains: A list of any alternate domains
-            that need to be listed with the primary distribution domain.
-        client_id: CLient ID.
-        distribution_domain: Distribution domain.
-        oauth_scopes: A list of all available validation
-            scopes for oauth.
-        redirect_path_sign_in: The redirect path after sign in.
-        redirect_path_sign_out: The redirect path after sign out.
-        supported_identity_providers: Supported identity providers.
 
     """
+    args = HookArgs.parse_obj(kwargs)
     session = context.get_session()
     cognito_client = session.client("cognito-idp")
 
     # Combine alternate domains with main distribution
-    redirect_domains = alternate_domains + ["https://" + distribution_domain]
+    redirect_domains = args.alternate_domains + ["https://" + args.distribution_domain]
 
     # Create a list of all domains with their redirect paths
     redirect_uris = get_redirect_uris(
-        redirect_domains, redirect_path_sign_in, redirect_path_sign_out
+        redirect_domains, args.redirect_path_sign_in, args.redirect_path_sign_out
     )
     # Update the user pool client
     try:
         cognito_client.update_user_pool_client(
-            AllowedOAuthScopes=oauth_scopes,
+            AllowedOAuthScopes=args.oauth_scopes,
             AllowedOAuthFlows=["code"],
-            SupportedIdentityProviders=supported_identity_providers or [],
+            SupportedIdentityProviders=args.supported_identity_providers,
             AllowedOAuthFlowsUserPoolClient=True,
-            ClientId=client_id,
+            ClientId=args.client_id,
             CallbackURLs=redirect_uris["sign_in"],
             LogoutURLs=redirect_uris["sign_out"],
             UserPoolId=context.hook_data["aae_user_pool_id_retriever"]["id"],
